// xref handling

a[data-type="xref"]{
    font-style: normal !important;
    &:before {
        content: '“';
    }
    &:after {
        content: '” on page ' target-counter(attr(href), page);
    } 
}

.missing-xref {
    font-style: normal !important;
}